@@ -34,7 +34,7 @@ class ActionAdmin(admin.ModelAdmin):
 @admin.register(UserRole, site=explorer_admin)
 class UserRoleAdmin(admin.ModelAdmin):
     list_display = ['user', 'volume', 'creation_date']
-    filter_horizontal = ['opertations']
+    filter_horizontal = ['actions']
     list_filter = ['user', 'volume']
     ordering = ('-user',)
     search_fields = ['user', 'volume']
\ No newline at end of file
