@@ -8,7 +8,7 @@ Description: Provide class to validate the user request.
 from explorer.views.extractor.request import RequestDataExtractor
 from explorer.views.extractor.user import UserDataExtractor
 
-from explorer.views.utils.path import is_path_exists
+from explorer.views.utils.path import is_path_exists, is_path_contain_reverse
 
 class Validator(RequestDataExtractor, UserDataExtractor):
     def __init__(self, request) -> None:
@@ -135,6 +135,8 @@ class Validator(RequestDataExtractor, UserDataExtractor):
                 valid = True
             else:
                 valid = is_path_exists(info[volume]['path'], location)
+                if valid:
+                    valid = is_path_contain_reverse(location)
         else:
             self.updateMessage(f'Invalid Request Method: {method}')
             valid = False
